@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20230831';
+our $VERSION = '0.20230929';
 
-# Table last modified: 2023-08-31
+# Table last modified: 2023-09-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -35,7 +35,7 @@ our %ZIP_TABLE = (
     '028' => '(?:(?:8(?:0(?:4[02]|3[01])|392|696)|7(?:39[2-7]|[15]92|995)|4(?:39[358]|19[35])|(?:0[135]|1[13])92|6(?:19[23568]|892)|3(?:69[2457]|392)|5495))',
     '029' => '(?:(?:4(?:19[245]|29[23]|59[23])|2(?:29[23]|396)|(?:01|56)92))',
     '030' => '(?:(?:8(?:5(?:3[03]|7[047]|8[058]|0[235]|[14][0135]|5[02-8]|2[0-4]|6[0167])|6(?:04|22|49|55|77|86|6[78]|1[01]))|01(?:9[26-8]|8[013-68])|1(?:49[26]|393|798)))',
-    '031' => '(?:8(?:5(?:20|4[3-5]|3[38]|5[0158]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[127]|0[18])))',
+    '031' => '(?:8(?:5(?:20|4[3-5]|3[38]|5[0158]|7[07]|8[58]|0[1457]|1[01])|6(?:55|86|1[17]|0[18])))',
     '033' => '(?:86(?:04|66|88))',
     '034' => '(?:(?:8(?:6(?:05|28|1[358])|5(?:65|78))|039[238]))',
     '035' => '(?:8686)',
@@ -107,7 +107,7 @@ our %ZIP_TABLE = (
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|5(?:1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[369]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|1[0-246-9]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
@@ -115,7 +115,7 @@ our %ZIP_TABLE = (
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|6[2369]|1[1246]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:88|1[1-3689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -248,7 +248,7 @@ our %ZIP_TABLE = (
     '266' => '(?:8(?:550|733))',
     '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
     '271' => '(?:8(?:5(?:01|22|3[03]|[18][058]|5[157]|6[02-4])|6(?:66|72|2[05])))',
-    '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|01(?:88|9[35])))',
+    '272' => '(?:(?:85(?:01|73|4[03]|5[058]|2[02]|8[0158]|1[0-468]|6[01]|3[038])|01(?:88|9[35])))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
@@ -566,11 +566,11 @@ our %ZIP_TABLE = (
     '597' => '(?:8(?:5(?:22|55|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
-    '600' => '(?:8(?:5(?:44|3[03]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07]|2[0256])|6(?:52|65|8[68])|7(?:11|87|92)))',
+    '600' => '(?:8(?:5(?:44|3[03]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07]|2[0256])|6(?:01|52|65|8[68])|7(?:11|87|92)))',
     '601' => '(?:(?:8(?:5(?:[26]0|42|88|3[03]|5[09]|0[126]|1[01])|601)|1(?:192|397|495)|0(?:292|797)))',
-    '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|6(?:02|11)))',
+    '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|6(?:02|11)|959))',
     '603' => '(?:85(?:11|22|55|77|88))',
-    '604' => '(?:8(?:5(?:20|1[015]|0[1258]|8[058]|7[178]|6[07]|5[01568])|666))',
+    '604' => '(?:8(?:5(?:20|1[015]|8[058]|7[178]|6[07]|5[01568]|0[125])|666))',
     '605' => '(?:8(?:5[01]1|686))',
     '606' => '(?:85(?:11|22|36|40|[58][58]|0[1257]))',
     '607' => '(?:85[017]1)',
